@@ -14,12 +14,12 @@
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111 USA.
+   Boston, MA 02110 USA.
    */
 
 #ifndef __NSDecimalNumber_h_GNUSTEP_BASE_INCLUDE
@@ -119,6 +119,7 @@ extern "C" {
  *  passing an instance as an argument to any [NSDecimalNumber] method ending
  *  with <code>...Behavior:</code>.
  */
+GS_EXPORT_CLASS
 @interface	NSDecimalNumberHandler : NSObject <NSDecimalNumberBehaviors>
 {
 #if	GS_EXPOSE(NSDecimalNumberHandler)
@@ -129,8 +130,14 @@ extern "C" {
   BOOL _raiseOnUnderflow;
   BOOL _raiseOnDivideByZero;
 #endif
-#if	!GS_NONFRAGILE
-  void	*_unused;
+#if     GS_NONFRAGILE
+#else
+  /* Pointer to private additional data used to avoid breaking ABI
+   * when we don't have the non-fragile ABI available.
+   * Use this mechanism rather than changing the instance variable
+   * layout (see Source/GSInternal.h for details).
+   */
+  @private id _internal GS_UNUSED_IVAR;
 #endif
 }
 
@@ -181,6 +188,7 @@ extern "C" {
  *
  *  <p>Note that instances of <code>NSDecimalNumber</code> are immutable.</p>
  */
+GS_EXPORT_CLASS
 @interface	NSDecimalNumber : NSNumber <NSDecimalNumberBehaviors>
 {
 #if	GS_EXPOSE(NSDecimalNumber)
@@ -305,7 +313,7 @@ extern "C" {
 /**
  *  Returns string version of number formatted according to locale.
  */
-- (NSString *)descriptionWithLocale:(NSDictionary *)locale;
+- (NSString *)descriptionWithLocale:(id)locale;
 
 /**
  *  Returns underlying value as a <code>double</code>, which may be an
