@@ -15,12 +15,12 @@
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
    
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111 USA.
+   Boston, MA 02110 USA.
    */ 
 
 #ifndef __NSInvocation_h_GNUSTEP_BASE_INCLUDE
@@ -33,6 +33,7 @@
 extern "C" {
 #endif
 
+GS_EXPORT_CLASS
 @interface NSInvocation : NSObject
 {
 #if	GS_EXPOSE(NSInvocation)
@@ -121,14 +122,14 @@ extern "C" {
 @end
 #endif
 
-/* Do NOT use these methods ... internal use only ... not public API */
+/** For use by macros only.
+ */
 @interface NSInvocation (MacroSetup)
+- (id) initWithMethodSignature: (NSMethodSignature*)aSignature;
 + (id) _newProxyForInvocation: (id)target;
 + (id) _newProxyForMessage: (id)target;
 + (NSInvocation*) _returnInvocationAndDestroyProxy: (id)proxy;
-- (id) initWithMethodSignature: (NSMethodSignature*)aSignature;
 @end
-
 /**
  *  Creates and returns an autoreleased invocation containing a
  *  message to an instance of the class.  The 'message' consists
