@@ -16,12 +16,12 @@
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
    
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111 USA.
+   Boston, MA 02110 USA.
    */ 
 
 #ifndef __NSProcessInfo_h_GNUSTEP_BASE_INCLUDE
@@ -30,6 +30,10 @@
 
 #import	<Foundation/NSObject.h>
 
+#ifdef __ANDROID__
+#include <jni.h>
+#endif
+
 #if	defined(__cplusplus)
 extern "C" {
 #endif
@@ -40,6 +44,24 @@ extern "C" {
 @class NSData;
 @class NSMutableSet;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_9,GS_API_LATEST) 
+typedef uint64_t NSActivityOptions;
+enum
+{
+  NSActivityIdleDisplaySleepDisabled = (1ULL << 40),
+  NSActivityIdleSystemSleepDisabled = (1ULL << 20),
+  NSActivitySuddenTerminationDisabled = (1ULL << 14),
+  NSActivityAutomaticTerminationDisabled = (1ULL << 15),
+
+  NSActivityUserInitiated = (0x00FFFFFFULL | NSActivityIdleSystemSleepDisabled),
+  NSActivityUserInitiatedAllowingIdleSystemSleep = (NSActivityUserInitiated & ~NSActivityIdleSystemSleepDisabled),
+
+  NSActivityBackground = 0x000000FFULL,
+
+  NSActivityLatencyCritical = 0xFF00000000ULL,
+};
+#endif
+
 #if OS_API_VERSION(GS_API_MACOSX,GS_API_LATEST)
 
 /**
@@ -76,6 +98,7 @@ enum {
 #endif	/* OS_API_VERSION(GS_API_MACOSX,GS_API_LATEST) */
 
 
+GS_EXPORT_CLASS
 @interface NSProcessInfo: NSObject
 
 /**
@@ -83,6 +106,14 @@ enum {
  */
 + (NSProcessInfo*) processInfo;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
+#if GS_HAS_DECLARED_PROPERTIES
+@property (readonly) NSUInteger systemUptime;
+#else
+- (NSUInteger) systemUptime;
+#endif
+#endif
+
 /**
  * Returns an array containing the arguments supplied to start this
  * process.<br />
@@ -166,7 +197,7 @@ enum {
  * Returns a human readable version string for the current operating system
  * version.
  */
-#if OS_API_VERSION(100200,GS_API_LATEST)
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_2,GS_API_LATEST)
 - (NSString *) operatingSystemVersionString;
 #endif
 
@@ -189,7 +220,7 @@ enum {
  */
 - (void) setProcessName: (NSString*)newName;
 
-#if OS_API_VERSION(100500,GS_API_LATEST) 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5,GS_API_LATEST) 
 /** Not implemented */
 - (NSUInteger) processorCount;
 /** Not implemented */
@@ -197,6 +228,25 @@ enum {
 /** Not implemented */
 - (unsigned long long) physicalMemory;
 #endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
+- (void) enableSuddenTermination;
+- (void) disableSuddenTermination;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_9,GS_API_LATEST) 
+DEFINE_BLOCK_TYPE_NO_ARGS(GSPerformActivityBlock, void);
+DEFINE_BLOCK_TYPE(GSPerformExpiringActivityBlock, void, BOOL);
+
+- (id) beginActivityWithOptions: (NSActivityOptions)options
+                         reason: (NSString *)reason;
+- (void) endActivity:(id<NSObject>)activity;
+- (void) performActivityWithOptions:(NSActivityOptions)options
+                            reason: (NSString *)reason
+                        usingBlock: (GSPerformActivityBlock)block;
+- (void) performExpiringActivityWithReason: (NSString *)reason
+            usingBlock: (GSPerformExpiringActivityBlock)block;
+#endif
 @end
 
 #if GS_API_VERSION(GS_API_NONE,011700)
@@ -220,6 +270,13 @@ enum {
 + (void) initializeWithArguments: (char**)argv
                            count: (int)argc
                      environment: (char**)env;
+
+#ifdef __ANDROID__
+- (jobject) androidContext;
+- (NSString *) androidFilesDir;
+- (NSString *) androidCacheDir;
+#endif
+
 @end
 
 /**
@@ -233,6 +290,16 @@ enum {
  */
 GS_EXPORT void GSInitializeProcess(int argc, char **argv, char **envp);
 
+#ifdef __ANDROID__
+/**
+ * Android process initialization function.
+ * This should be called on Android to initialize GNUstep with the JNI
+ * environment and application context, which is used to set up support
+ * for the Android data directory and asset loading via NSBundle.
+ */
+GS_EXPORT void GSInitializeProcessAndroid(JNIEnv *env, jobject context);
+#endif
+
 /**
  * Function for rapid testing to see if a debug level is set.<br />
  * This is used by the debugging macros.<br />
