@@ -14,12 +14,12 @@
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111 USA.
+   Boston, MA 02110 USA.
 */ 
 
 #ifndef __NSScanner_h_GNUSTEP_BASE_INCLUDE
@@ -37,6 +37,7 @@ extern "C" {
 /*
  * NSScanner class
  */
+GS_EXPORT_CLASS
 @interface NSScanner : NSObject <NSCopying>
 {
 #if	GS_EXPOSE(NSScanner)
@@ -106,18 +107,19 @@ extern "C" {
 
 #if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 - (BOOL) scanRadixUnsignedInt: (unsigned int*)value;
+- (BOOL) scanRadixUnsignedLongLong: (unsigned long long*)value;
 #endif
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (BOOL) scanDecimal: (NSDecimal*)value;
 #endif
+
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (BOOL) scanHexLongLong: (unsigned long long*)value;
 /** Not implemented */
 - (BOOL) scanHexDouble: (double *)result;
 /** Not implemented */
 - (BOOL) scanHexFloat: (float *)result;
 /** Not implemented */
-- (BOOL) scanHexLongLong: (unsigned long long *)result;
-/** Not implemented */
 - (BOOL) scanInteger: (NSInteger *)value;
 #endif
 @end
